@@ -25,31 +25,31 @@ def text_examples():
     print("=== Text Component Examples ===")
 
     # 1. Basic text
-    basic_text = TextContent(config=TextConfig(text="Hello pysvg!", x=100, y=50))
+    basic_text = TextContent("Hello pysvg!", config=TextConfig(x=100, y=50))
     print(f"Basic text: {basic_text.to_svg_element()}")
 
     # 2. Custom styled text
     styled_text = TextContent(
+        "Styled Text",
         config=TextConfig(
-            text="Styled Text",
             x=100,
             y=100,
             font_size=24,
             font_family="Times New Roman",
             color=Color("blue"),
-        )
+        ),
     )
     print(f"Styled text: {styled_text.to_svg_element()}")
 
     # 3. Alignment examples
     aligned_text = TextContent(
+        "Right Aligned",
         config=TextConfig(
-            text="Right Aligned",
             x=200,
             y=150,
             text_anchor="end",  # Right aligned
             dominant_baseline="hanging",  # Top aligned
-        )
+        ),
     )
     print(f"Aligned text: {aligned_text.to_svg_element()}")
     print()
@@ -60,28 +60,27 @@ def image_examples():
     print("=== Image Component Examples ===")
 
     # 1. Basic image
-    basic_image = ImageContent(
-        config=ImageConfig(href="demo.png", x=50, y=50, width=100, height=100)
-    )
+    basic_image = ImageContent("demo.png", config=ImageConfig(x=50, y=50, width=100, height=100))
     print(f"Basic image: {basic_image.to_svg_element()}")
 
     # 2. Image with adjusted size and position
     positioned_image = ImageContent(
+        "demo.png",
         config=ImageConfig(
-            href="demo.png",
             x=200,
             y=50,
             width=150,
             height=100,
             preserveAspectRatio="xMidYMid slice",  # Fill mode
-        )
+        ),
     )
     print(f"Positioned image: {positioned_image.to_svg_element()}")
 
     # 3. Image with transform
     transformed_image = (
         ImageContent(
-            config=ImageConfig(href="demo.png", x=400, y=50, width=100, height=100),
+            "demo.png",
+            config=ImageConfig(x=400, y=50, width=100, height=100),
         )
         .rotate(45)
         .scale(0.8)
@@ -100,47 +99,46 @@ def generate_demo_svg():
     # Add text examples
     text_components = [
         TextContent(
+            "Left aligned",
             config=TextConfig(
-                text="Left aligned",
                 x=100,
                 y=100,
                 font_size=20,
                 text_anchor="start",
                 color=Color("purple"),
-            )
+            ),
         ),
         TextContent(
-            config=TextConfig(
-                text="Center aligned", x=400, y=100, font_size=20, color=Color("green")
-            )
+            "Center aligned", config=TextConfig(x=400, y=100, font_size=20, color=Color("green"))
         ),
         TextContent(
+            "Right aligned",
             config=TextConfig(
-                text="Right aligned",
                 x=700,
                 y=100,
                 font_size=20,
                 text_anchor="end",
                 color=Color("red"),
-            )
+            ),
         ),
     ]
 
     # Add image/svg examples
     image_components = [
-        ImageContent(config=ImageConfig(href="demo.png", x=100, y=150, width=150, height=150)),
+        ImageContent("demo.png", config=ImageConfig(x=100, y=150, width=150, height=150)),
         ImageContent(
-            config=ImageConfig(href="demo.png", x=325, y=150, width=150, height=150),
+            "demo.png",
+            config=ImageConfig(x=325, y=150, width=150, height=150),
         ).rotate(45),
         ImageContent(
+            "demo.svg",
             config=ImageConfig(
-                href="demo.svg",
                 x=550,
                 y=150,
                 width=150,
                 height=150,
                 preserveAspectRatio="xMidYMid slice",
-            )
+            ),
         ),
     ]
 
