@@ -18,7 +18,7 @@ from pysvg.components import Matrix, MatrixConfig
 from pysvg.components.content import TextContent, TextConfig
 from pysvg.schema import AppearanceConfig, Color
 from pysvg.components.canvas import Canvas
-from pysvg.utils import get_nestls_elem
+from pysvg.utils import get_list_elem
 
 
 def chess_board_example():
@@ -50,7 +50,7 @@ def chess_board_example():
     matrix = Matrix(
         data=chess_data,
         background_map=bgmap,
-        border_as_number="upperleft",  # Use upper left corner for coordinate labels
+        border_as_coord="upperleft",  # Use upper left corner for coordinate labels
         coord_font_size=16,  # Coordinate text font size
         coord_font_family="Arial",  # Coordinate text font family
         coord_font_color=Color("darkblue"),  # Coordinate text color
@@ -74,7 +74,7 @@ def custom_border_style_example():
     # Simple 3x3 data grid
     data = [["", "Col1", "Col2"], ["Row1", "DataA", "DataB"], ["Row2", "DataC", "DataD"]]
 
-    all_elems = get_nestls_elem(data)
+    all_elems = get_list_elem(data)
     bgmap = {
         elem: AppearanceConfig(fill=Color("lightyellow"), stroke=Color("blue"), stroke_width=2)
         for elem in all_elems
@@ -84,7 +84,7 @@ def custom_border_style_example():
     matrix = Matrix(
         data=data,
         background_map=bgmap,
-        border_as_number="upperleft",
+        border_as_coord="upperleft",
         coord_font_size=18,  # Larger font
         coord_font_family="Times",  # Different font family
         coord_font_color=Color("red"),  # Red coordinate text
@@ -141,7 +141,7 @@ def different_border_positions_example():
     position_names = ["Upper Left", "Upper Right", "Lower Left", "Lower Right"]
     colors = [Color("purple"), Color("green"), Color("orange"), Color("navy")]
 
-    all_elems = get_nestls_elem(base_data[0])
+    all_elems = get_list_elem(base_data[0])
     bgmap = {
         elem: AppearanceConfig(fill=Color("lightcyan"), stroke=Color("gray"), stroke_width=1)
         for elem in all_elems
@@ -152,7 +152,7 @@ def different_border_positions_example():
 
         matrix = Matrix(
             data=base_data[i],
-            border_as_number=position,
+            border_as_coord=position,
             coord_font_color=color,
             coord_font_size=14,
             background_map=bgmap,
@@ -193,7 +193,7 @@ def game_board_with_caption_example():
     matrix = Matrix(
         data=gomoku_data,
         background_map=bgmap,
-        border_as_number="upperleft",
+        border_as_coord="upperleft",
         coord_font_size=14,
         coord_font_color=Color("saddlebrown"),
         caption=caption,
@@ -220,16 +220,14 @@ def priority_demonstration_example():
 
     data = [["", "Col1", "Col2"], ["Row1", "Data1", "Data2"], ["Row2", "Data3", "Data4"]]
 
-    all_elems = get_nestls_elem(data)
+    all_elems = get_list_elem(data)
     bgmap = {
         elem: AppearanceConfig(fill=Color("yellow"), stroke=Color("black"), stroke_width=3)
         for elem in all_elems
     }
     element_map = {
         elem: TextContent(
-            config=TextConfig(
-                text=str(elem), color=Color("blue"), font_family="Times", font_size=20
-            )
+            str(elem), config=TextConfig(color=Color("blue"), font_family="Times", font_size=20)
         )
         for elem in all_elems
     }
@@ -239,7 +237,7 @@ def priority_demonstration_example():
         data=data,
         background_map=bgmap,
         element_map=element_map,
-        border_as_number="upperleft",
+        border_as_coord="upperleft",
         coord_font_size=16,
         coord_font_color=Color("red"),
         config=MatrixConfig(cell_size=50),
@@ -272,8 +270,8 @@ def generate_demo_svg():
     # # Add different position examples
     position_matrices = different_border_positions_example()
     canvas.add(position_matrices[0].move_by(0, 20 + 400))
-    canvas.add(position_matrices[1].move_by(250, 20 + 430))
-    canvas.add(position_matrices[2].move_by(500, 20 + 400))
+    canvas.add(position_matrices[1].move_by(250, 20 + 400))
+    canvas.add(position_matrices[2].move_by(500, 20 + 430))
     canvas.add(position_matrices[3].move_by(750, 20 + 430))
 
     # # Add game board example
