@@ -45,8 +45,8 @@ def element_mapping_examples():
 
     # Element mapping: 0 -> "Empty", 1 -> "Full"
     element_map = {
-        0: TextContent(config=TextConfig(text="Empty")),
-        1: TextContent(config=TextConfig(text="Full")),
+        0: TextContent("Empty"),
+        1: TextContent("Full"),
     }
 
     mapped_matrix = Matrix(data=data, element_map=element_map, config=MatrixConfig(cell_size=60))
@@ -103,7 +103,7 @@ def caption_examples():
         caption=caption,
         caption_font_size=16,
         caption_font_color=Color("black"),
-        caption_location="down",
+        caption_location="bottom",
         config=MatrixConfig(cell_size=60),
     )
     print(f"Bottom caption: {down_caption_matrix.to_svg_element()}")
@@ -141,8 +141,8 @@ def comprehensive_example():
 
     # Element mapping
     element_map = {
-        0: TextContent(config=TextConfig(text="○")),
-        1: TextContent(config=TextConfig(text="●", color=Color("gray"))),
+        0: TextContent("○"),
+        1: TextContent("●", config=TextConfig(color=Color("gray"))),
     }
 
     # Element appearance mapping
@@ -200,14 +200,14 @@ def generate_demo_svg():
             background_map=bgmap,
             config=MatrixConfig(cell_size=60),
         )
-    ).move_by(290, 50)
+    ).move_by(260, 50)
     canvas.add(colored_matrix)
 
     # 3. Matrix with caption
     caption_data = [[1, 0, 1], [0, 1, 0], [1, 0, 1]]
     element_map = {
-        0: TextContent(config=TextConfig(text="○")),
-        1: TextContent(config=TextConfig(text="●")),
+        0: TextContent("○"),
+        1: TextContent("●"),
     }
     caption = "Pattern Matrix"
     caption_matrix = Matrix(
@@ -245,7 +245,7 @@ def generate_demo_svg():
     bgmap = {i: appearance for i in range(1, 21)}
     large_matrix = (
         Matrix(data=large_data, background_map=bgmap, config=MatrixConfig(cell_size=40))
-    ).move_by(270, 250)
+    ).move_by(250, 250)
     canvas.add(large_matrix)
 
     # 6. Checkerboard pattern (comprehensive example)
@@ -257,8 +257,8 @@ def generate_demo_svg():
         [1, 0, 1, 0, 1],
     ]
     checkerboard_map = {
-        0: TextContent(config=TextConfig(text="")),
-        1: TextContent(config=TextConfig(text="")),
+        0: TextContent(""),
+        1: TextContent(""),
     }
     checkerboard_appearance = {
         0: AppearanceConfig(fill=Color("white"), stroke=Color("black"), stroke_width=1),
@@ -270,7 +270,7 @@ def generate_demo_svg():
         element_map=checkerboard_map,
         background_map=checkerboard_appearance,
         caption=checkerboard_caption,
-        caption_location="down",
+        caption_location="bottom",
         caption_font_size=18,
         caption_font_color=Color("darkgreen"),
         config=MatrixConfig(cell_size=40),
