@@ -6,8 +6,6 @@ from pysvg.schema import TransformConfig, Color, BBox, ComponentConfig
 from pysvg.components.base import BaseSVGComponent
 from pysvg.logger import get_logger
 
-_logger = get_logger(__name__)
-
 
 class TextConfig(ComponentConfig):
     """Geometry configuration for Text components"""
@@ -18,7 +16,6 @@ class TextConfig(ComponentConfig):
     y: float = Field(
         default=0, description="Text y position , central(default) or left-upper corner)"
     )
-    text: str = Field(default="", description="Text content to display")
     font_size: float = Field(default=12, ge=0, description="Font size")
     font_family: str = Field(default="Arial", description="Font family")
     color: Color = Field(default=Color("black"), description="Text color")
@@ -41,8 +38,6 @@ class TextConfig(ComponentConfig):
         }
         if "color" in attrs:
             attrs["fill"] = attrs.pop("color")
-        if "text" in attrs:
-            del attrs["text"]
         return attrs
 
 
@@ -53,7 +48,6 @@ class ImageConfig(ComponentConfig):
     y: float = Field(default=0, description="Image y position")
     width: float = Field(default=200, ge=0, description="Image width")
     height: float = Field(default=200, ge=0, description="Image height")
-    href: str = Field(description="Image path or URL")
     preserveAspectRatio: str = Field(
         default="xMidYMid meet", description="How to preserve aspect ratio"
     )
@@ -68,12 +62,16 @@ class ImageConfig(ComponentConfig):
 class TextContent(BaseSVGComponent):
     """Text content component for SVG"""
 
-    def __init__(self, config: TextConfig, transform: TransformConfig | None = None):
-        super().__init__(config=config, transform=transform if transform else TransformConfig())
+    def __init__(
+        self, text: str, config: TextConfig | None = None, transform: TransformConfig | None = None
+    ):
+        super().__init__(config=config or TextConfig(), transform=transform or TransformConfig())
+        self.text = text
 
     @override
     @property
     def central_point_relative(self) -> Tuple[float, float]:
+        _logger = get_logger(self.__class__.__name__)
         if self.config.dominant_baseline != "central":
             raise RuntimeWarning(
                 "When dominant_baseline is not central, we can't determine the relative central point of the text"
@@ -96,18 +94,29 @@ class TextContent(BaseSVGComponent):
             "Can't get bounding box of text content since we can't determine the size of the text"
         )
 
+    @override
+    def restrict_size(
+        self, width: float, height: float, mode: Literal["fit", "force"] = "fit"
+    ) -> "TextContent":
+        raise RuntimeWarning(
+            "Can't restrict size of text content since we can't determine the size of the text"
+        )
+
     @override
     def to_svg_element(self) -> str:
         attrs = self.get_attr_dict()
         attrs_ls = [f'{k}="{v}"' for k, v in attrs.items()]
-        return f"<text {' '.join(attrs_ls)}>{self.config.text}</text>"
+        return f"<text {' '.join(attrs_ls)}>{self.text}</text>"
 
 
 class ImageContent(BaseSVGComponent):
     """Image content component for SVG"""
 
-    def __init__(self, config: ImageConfig, transform: TransformConfig | None = None):
-        super().__init__(config=config, transform=transform if transform else TransformConfig())
+    def __init__(
+        self, href: str, config: ImageConfig | None = None, transform: TransformConfig | None = None
+    ):
+        super().__init__(config=config or ImageConfig(), transform=transform or TransformConfig())
+        self.href = href
 
     @override
     @property
@@ -125,8 +134,20 @@ class ImageContent(BaseSVGComponent):
             height=self.config.height,
         )
 
+    @override
+    def restrict_size(
+        self, width: float, height: float, mode: Literal["fit", "force"] = "fit"
+    ) -> "ImageContent":
+        ratio = min(width / self.config.width, height / self.config.height)
+        if mode == "fit" and ratio >= 1.0:
+            return self
+        self.config.width = self.config.width * ratio
+        self.config.height = self.config.height * ratio
+        return self
+
     @override
     def to_svg_element(self) -> str:
         attrs = self.get_attr_dict()
+        attrs["href"] = self.href
         attrs_ls = [f'{k}="{v}"' for k, v in attrs.items()]
         return f"<image {' '.join(attrs_ls)} />"
